#!/bin/bash
# Auto generate jsdl files for test applications
#
# Copyright 2009 INRIA, All rights reserved
#
# Author:
#   Eugen Feller <eugen.feller@uni-duesseldorf.de>
#
# Syntax:
# ./generate_jsdl.sh destination
###

APPS="bi bi-cr bi-file bi-signal bi-double bi-clone-files bi-clone-fs bi-clone-semundo bi-thread maw mgs fft sor jacobi pipe-counting"
DEST_DIR=$1

generate_one_file ()
{
	local dest_dir=$1
	local app_name=$2
	
	echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
		<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/10/jsdl\">
			<JobDescription>
				<JobIdentification>
					<Description>Local test application: $app_name</Description>
					<JobProject>GridCP Test</JobProject>
				</JobIdentification>
				<Application>
					<POSIXApplication xmlns:ns1=\"http://schemas.ggf.org/jsdl/2005/06/jsdlposix\">
						<Executable>$app_name</Executable>
						<Argument> </Argument>
						<Output>out_$app_name.txt</Output>
						<Error>err_$app_name.txt</Error>
					</POSIXApplication>
				</Application>
			</JobDescription>
		</JobDefinition>" > $dest_dir/$app_name.jsdl

	echo "$app_name.jsdl: done"
}

generate_jsdl_files() 
{
	local dest_dir=$1

	for app_name in ${APPS[@]}
	do
		if [ ! -f $dest_dir/$app_name.jsdl ]
		then
			generate_one_file $dest_dir $app_name
		else
			echo "$app_name.jsdl: already exists!"
		fi
	done
}


if [ $# -ne 1 ]
then
	echo "Please specify the destination directory!"
	exit 1
elif [ ! -d $DEST_DIR ] 
then
	echo "Specified directory does not exist!"
	exit 1
fi

generate_jsdl_files $DEST_DIR

exit 0
